@@ -1,5 +1,4 @@
-"""Module for a 3-dimensional Euclidean vector space with a vector and matrix type as well as necessary methods to use 
-them.
+"""Module for a 3-dimensional Euclidean vector space with a vector and matrix type as well as necessary methods to use them.
 
 """
 
